@@ -2,6 +2,7 @@ import httpx
 from typing import Dict, Any, Optional
 import json
 import logging
+import time
 import uuid
 
 from .models import InstanceResponse
@@ -25,7 +26,7 @@ from .exceptions import (
 try:
     from . import __version__
 except ImportError:
-    __version__ = "0.2.70"
+    __version__ = "0.2.72"
 
 logger = logging.getLogger(__name__)
 
@@ -51,11 +52,14 @@ class BaseWrapper:
             "X-Fleet-SDK-Version": __version__,
         }
         headers["Authorization"] = f"Bearer {self.api_key}"
-        
+
         # Add request ID for idempotency (persists across retries)
         if request_id:
             headers["X-Request-ID"] = request_id
-        
+
+        # Add timestamp for all requests
+        headers["X-Request-Timestamp"] = str(int(time.time() * 1000))
+
         return headers
 
 
